//    GeoExp is a 3D Studio Max plugin that export GEO files.
//    Copyright (C) 1999  Anders Reggestad (andersr@pvv.ntnu.no)
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
#ifndef __GEOEXP__H
#define __GEOEXP__H

#define VERSION			111			// Version number * 100

//	Change log
//
//	1.11 30/7-1999
//		Don't export hidden objects
//  1.10 30/7-1999 
//		Fixed bug in normallist output code.
//		Included epsilon value test to normal comparison
//		Updated VERSION to 110 to reflect information writen in resource file.
//	1.00 10/5-1999
//		First version


#include "Max.h"
#include "resource.h"
#include "istdplug.h"
#include "stdmat.h"
#include "shape.h"
#include "normal.h"


extern ClassDesc* GetGeoOutDesc();
extern TCHAR *GetString(int id);
extern HINSTANCE hInstance;

#define NORMAL_EPSILON  0.0001f

class GeoOut : public SceneExport {
public:
	GeoOut();
	~GeoOut();

	// SceneExport methods
	int    ExtCount();     // Number of extensions supported 
	const TCHAR * Ext(int n);     // Extension #n (i.e. "ASC")
	const TCHAR * LongDesc();     // Long ASCII description (i.e. "Ascii Export") 
	const TCHAR * ShortDesc();    // Short ASCII description (i.e. "Ascii")
	const TCHAR * AuthorName();    // ASCII Author name
	const TCHAR * CopyrightMessage();   // ASCII Copyright message 
	const TCHAR * OtherMessage1();   // Other message #1
	const TCHAR * OtherMessage2();   // Other message #2
	unsigned int Version();     // Version number * 100 (i.e. v3.01 = 301) 
	void	ShowAbout(HWND hWnd);  // Show DLL's "About..." box
	int		DoExport(const TCHAR *name,ExpInterface *ei,Interface *i, BOOL suppressPrompts=FALSE); // Export	file
	// Other methods

	// Node enumeration
	BOOL	nodeEnum(INode* node, int indentLevel);
	void	PreProcess(INode* node, int& nodeCount);

	// High level export
	void	ExportGlobalInfo();
	void	ExportGeomObject(INode* node, int indentLevel); 

	// Misc methods
	TSTR	GetIndent(int indentLevel);
	TCHAR*	FixupName(TCHAR* name);
	void	CommaScan(TCHAR* buf);
	TriObject*	GetTriObjectFromNode(INode *node, TimeValue t, int &deleteIt);

	// A collection of overloaded value to string converters.
	TSTR	Format(int value);
	TSTR	Format(float value);
	TSTR	Format(Color value);
	TSTR	Format(Point3 value); 
	TSTR	Format(AngAxis value); 
	TSTR	Format(Quat value);
	TSTR	Format(ScaleValue value);

	// Interface to member variables
	inline int	GetPrecision()				{ return nPrecision; }
	inline Interface*	GetInterface()		{ return ip; }
	inline TimeValue GetStaticFrame()		{ return nStaticFrame; }

	inline void SetStaticFrame(TimeValue val)		{ nStaticFrame = val; }
	inline void SetPrecision(int val)				{ nPrecision = val; }

private:
	int			nPrecision;
 	TimeValue	nStaticFrame;
	Interface*	ip;
	FILE*		pStream;
	int			nTotalNodeCount;
	int			nCurNode;
	TCHAR		szFmtStr[16];

};

#endif // __GEOEXP__H